==> ejc-bid-impl-3.0.0-20221208.083005-294-sources.jar: com/ejianc/business/bid/controller/InfoTrackController.java <==
package com.ejianc.business.bid.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.bid.bean.TrackProjectEntity;
import com.ejianc.business.bid.bean.TrackProjectZiEntity;
import com.ejianc.business.bid.consts.BidCommonConsts;
import com.ejianc.business.bid.consts.BidStateEnum;
import com.ejianc.business.bid.consts.BiddingFormEnum;
import com.ejianc.business.bid.service.*;
import com.ejianc.business.bid.vo.TrackProjectVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

import com.ejianc.business.bid.bean.InfoTrackEntity;
import com.ejianc.business.bid.vo.InfoTrackVO;

/**
 * 投标信息跟踪
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("infoTrack")
@Api(value = "投标信息跟踪", tags = {"投标信息跟踪"})
public class InfoTrackController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;
    /**此处需要根据实际修改 */
    private static final String BILL_CODE = "BID_01";

    @Autowired
    private IInfoTrackService service;
    @Autowired
    private IRecordService recordService;
    @Autowired
    private IInfoTrackStopService infoTrackStopService;
    @Autowired
    private ITrackProjectService trackProjectService;
    @Autowired
    private ITrackProjectZiService trackProjectZiService;

    @ApiOperation("新增或者修改")
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<InfoTrackVO> saveOrUpdate(@ApiParam(name="saveorUpdateVO", required=true) @RequestBody InfoTrackVO saveorUpdateVO) {
    	InfoTrackEntity entity = BeanMapper.map(saveorUpdateVO, InfoTrackEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            //新增 默认未中止 0
            entity.setIsStop(BidCommonConsts.NO);
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveorUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                //此处需要根据实际修改 删除本行或者上一行
                entity.setBillCode(billCode.getData());
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
        //
        if (entity.getTrackProjectId() != null) {
            TrackProjectEntity trackProjectEntity = trackProjectService.getById(entity.getTrackProjectId());

            trackProjectEntity.setTrackNum(trackProjectEntity.getTrackNum()+1);//跟踪次数+1
            trackProjectService.saveOrUpdate(trackProjectEntity);

            TrackProjectZiEntity trackProjectZiEntity = new TrackProjectZiEntity();
            trackProjectZiEntity.setZhuId(entity.getTrackProjectId());
            trackProjectZiEntity.setDepartmentId(entity.getFollowUnit());
            trackProjectZiEntity.setDepartmentName(entity.getFollowUnitName());
            trackProjectZiService.save(trackProjectZiEntity);



            //更新所有已提交表单的跟踪次数
            LambdaUpdateWrapper<InfoTrackEntity> updateWrapper = new LambdaUpdateWrapper<>();
            updateWrapper
                    .set(InfoTrackEntity::getTrackNum,entity.getTrackNum())
                    .eq(InfoTrackEntity::getTrackProjectId,entity.getTrackProjectId());
            service.update(updateWrapper);
        }


    	service.saveOrUpdate(entity, false);
    	InfoTrackVO vo = BeanMapper.map(entity, InfoTrackVO.class);
        infoTrackStopService.insertInfoTrackStop(vo);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }


    @ApiOperation("查询详情")
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<InfoTrackVO> queryDetail(@RequestParam Long id) {
    	InfoTrackEntity entity = service.selectById(id);
    	InfoTrackVO vo = BeanMapper.map(entity, InfoTrackVO.class);
        vo.setRecords(recordService.getRecord(vo.getBillCode()));
        if(vo != null){
            vo.setBiddingFormName(BiddingFormEnum.getNameByCode(vo.getBiddingForm()));
            vo.setFollowStateName(BidStateEnum.getNameByCode(vo.getFollowState()));
        }
        return CommonResponse.success("查询详情数据成功！",vo);
    }


    @ApiOperation("批量删除单据")
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<InfoTrackVO> vos) {
        service.removeByIds(vos.stream().map(InfoTrackVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }


    @ApiOperation("查询")
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<InfoTrackVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("engineeringName");
        //跟踪单位
        fuzzyFields.add("followUnitName");
        //编制人
        fuzzyFields.add("employeeName");
        //投标主管名称
        fuzzyFields.add("projectBidManageName");
        //招标代理机构
        fuzzyFields.add("biddingAgency");
        //建造单位
        fuzzyFields.add("constructionUnitName");
        //单位负责人
        fuzzyFields.add("unitDirectorName");
        //工程类型
        fuzzyFields.add("engineeringTypeName");
        //地点
        fuzzyFields.add("address");
        //跟踪项目名称
        fuzzyFields.add("trackProjectName");

        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        Parameter orgIdValue = param.getParams().get("orgId");
        Long orgId = orgIdValue == null || orgIdValue.getValue() == null ? InvocationInfoProxy.getOrgId() : Long.valueOf(String.valueOf(orgIdValue.getValue()));
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        param.getOrderMap().put("createTime", QueryParam.DESC);

        IPage<InfoTrackEntity> page = service.queryPage(param,false);
        IPage<InfoTrackVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), InfoTrackVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    @ApiOperation("导出")
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("followUnitName");
        fuzzyFields.add("employeeName");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        Parameter orgIdValue = param.getParams().get("orgId");
        Long orgId = orgIdValue == null || orgIdValue.getValue() == null ? InvocationInfoProxy.getOrgId() : Long.valueOf(String.valueOf(orgIdValue.getValue()));
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        param.getOrderMap().put("createTime", QueryParam.DESC);
        List<InfoTrackEntity> list = service.queryList(param);

        List<InfoTrackVO> voList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(list)) {
            voList = BeanMapper.mapList(list, InfoTrackVO.class);
            voList.forEach(vo -> {
                vo.setBillStateName(BillStateEnum.getEnumByStateCode(vo.getBillState()).getDescription());
                vo.setFollowStateName(BidStateEnum.getNameByCode(vo.getFollowState()));
            });
        }

        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", voList);
        ExcelExport.getInstance().export("InfoTrack-export.xlsx", beans, response);
    }


    @ApiOperation("参照")
    @RequestMapping(value = "/refInfoTrackData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<InfoTrackVO>> refInfoTrackData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("unitDirectorName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        /** 查询未中止 */
        param.getParams().put("isStop", new Parameter(QueryParam.EQ , BidCommonConsts.NO));
        /** 数据隔离 本下 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        /** 跟踪中 **/
        param.getParams().put("followState", new Parameter(QueryParam.EQ , BidCommonConsts.YES));
        /** 已通过 **/
        param.getParams().put("billState", new Parameter(QueryParam.IN,
                Arrays.asList(new Integer[]{BillStateEnum.COMMITED_STATE.getBillStateCode(), BillStateEnum.PASSED_STATE.getBillStateCode()})));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject con = JSONObject.parseObject(condition);
        }

        IPage<InfoTrackEntity> page = service.queryPage(param,false);
        IPage<InfoTrackVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), InfoTrackVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
@Autowired
private TrackProjectController trackProjectController;

    @ApiOperation("推送一条跟踪项目")
    @RequestMapping(value = "/pushTrackProject", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<InfoTrackVO> pushTrackProject(@ApiParam(name="infoTrackVO", required=true) @RequestBody InfoTrackVO infoTrackVO) {
        InfoTrackEntity entity = BeanMapper.map(infoTrackVO, InfoTrackEntity.class);
        TrackProjectVO trackProjectVO = new TrackProjectVO();
        trackProjectVO.setProjectName(entity.getEngineeringName());
        trackProjectVO.setOrgId(InvocationInfoProxy.getOrgId());
        trackProjectVO.setTrackNum(0);
        trackProjectVO.setUseState(1);
        trackProjectController.saveOrUpdate(trackProjectVO);
        return CommonResponse.success("保存或修改单据成功！",infoTrackVO);
    }
}

==> ejc-bid-impl-3.0.0-20231024.110845-389-sources.jar: com/ejianc/business/bid/controller/InfoTrackController.java <==
package com.ejianc.business.bid.controller;

import java.io.Serializable;

import com.ejianc.business.bid.consts.BidCommonConsts;
import com.ejianc.business.bid.consts.BidStateEnum;
import com.ejianc.business.bid.consts.BiddingFormEnum;
import com.ejianc.business.bid.service.IInfoTrackStopService;
import com.ejianc.business.bid.service.IRecordService;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;

import com.ejianc.business.bid.bean.InfoTrackEntity;
import com.ejianc.business.bid.service.IInfoTrackService;
import com.ejianc.business.bid.vo.InfoTrackVO;

/**
 * 投标信息跟踪
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("infoTrack")
@Api(value = "投标信息跟踪", tags = {"投标信息跟踪"})
public class InfoTrackController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;
    /**此处需要根据实际修改 */
    private static final String BILL_CODE = "BID_ENGINEERING_CODE";

    @Autowired
    private IInfoTrackService service;
    @Autowired
    private IRecordService recordService;
    @Autowired
    private IInfoTrackStopService infoTrackStopService;


    @ApiOperation("新增或者修改")
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<InfoTrackVO> saveOrUpdate(@ApiParam(name="saveorUpdateVO", required=true) @RequestBody InfoTrackVO saveorUpdateVO) {
    	InfoTrackEntity entity = BeanMapper.map(saveorUpdateVO, InfoTrackEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            //新增 默认未中止 0
            entity.setIsStop(BidCommonConsts.NO);
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveorUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                //此处需要根据实际修改 删除本行或者上一行
                entity.setBillCode(billCode.getData());
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
    	service.saveOrUpdate(entity, false);
    	InfoTrackVO vo = BeanMapper.map(entity, InfoTrackVO.class);
        infoTrackStopService.insertInfoTrackStop(vo);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }


    @ApiOperation("查询详情")
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<InfoTrackVO> queryDetail(@RequestParam Long id) {
    	InfoTrackEntity entity = service.selectById(id);
    	InfoTrackVO vo = BeanMapper.map(entity, InfoTrackVO.class);
        vo.setRecords(recordService.getRecord(vo.getBillCode()));
        if(vo != null){
            vo.setBiddingFormName(BiddingFormEnum.getNameByCode(vo.getBiddingForm()));
            vo.setFollowStateName(BidStateEnum.getNameByCode(vo.getFollowState()));
        }
        return CommonResponse.success("查询详情数据成功！",vo);
    }


    @ApiOperation("批量删除单据")
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<InfoTrackVO> vos) {
        service.removeByIds(vos.stream().map(InfoTrackVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }


    @ApiOperation("查询")
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<InfoTrackVO>> queryList(@RequestBody QueryParam param) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("followUnitName");
        fuzzyFields.add("employeeName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        Parameter orgIdValue = param.getParams().get("orgId");
        Long orgId = orgIdValue == null || orgIdValue.getValue() == null ? InvocationInfoProxy.getOrgId() : Long.valueOf(String.valueOf(orgIdValue.getValue()));
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        param.getOrderMap().put("createTime", QueryParam.DESC);

        IPage<InfoTrackEntity> page = service.queryPage(param,false);
        IPage<InfoTrackVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), InfoTrackVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }


    @ApiOperation("导出")
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("followUnitName");
        fuzzyFields.add("employeeName");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        Parameter orgIdValue = param.getParams().get("orgId");
        Long orgId = orgIdValue == null || orgIdValue.getValue() == null ? InvocationInfoProxy.getOrgId() : Long.valueOf(String.valueOf(orgIdValue.getValue()));
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        param.getOrderMap().put("createTime", QueryParam.DESC);
        List<InfoTrackEntity> list = service.queryList(param);

        List<InfoTrackVO> voList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(list)) {
            voList = BeanMapper.mapList(list, InfoTrackVO.class);
            voList.forEach(vo -> {
                vo.setBillStateName(BillStateEnum.getEnumByStateCode(vo.getBillState()).getDescription());
                vo.setFollowStateName(BidStateEnum.getNameByCode(vo.getFollowState()));
            });
        }

        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", voList);
        ExcelExport.getInstance().export("InfoTrack-export.xlsx", beans, response);
    }


    @ApiOperation("参照")
    @RequestMapping(value = "/refInfoTrackData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<InfoTrackVO>> refInfoTrackData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("engineeringName");
        fuzzyFields.add("unitDirectorName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        /** 查询未中止 */
        param.getParams().put("isStop", new Parameter(QueryParam.EQ , BidCommonConsts.NO));
        /** 数据隔离 本下 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        /** 跟踪中 **/
        param.getParams().put("followState", new Parameter(QueryParam.EQ , BidCommonConsts.YES));
        /** 已通过 **/
        param.getParams().put("billState", new Parameter(QueryParam.IN,
                Arrays.asList(new Integer[]{BillStateEnum.COMMITED_STATE.getBillStateCode(), BillStateEnum.PASSED_STATE.getBillStateCode()})));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject con = JSONObject.parseObject(condition);
        }

        IPage<InfoTrackEntity> page = service.queryPage(param,false);
        IPage<InfoTrackVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), InfoTrackVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}
